from pathlib import Path

PACKAGE_DIR = Path(__file__).parent

APPLESCRIPT_LAUNCHER = 'osascript'
APPLESCRIPT_NAME = 'findersel.applescript'
APPLESCRIPT_PATH = PACKAGE_DIR / 'scripts' / APPLESCRIPT_NAME



import subprocess

from findersel import settings


def get_selected_files(*, sort=False):
    cmd = f'{settings.APPLESCRIPT_LAUNCHER} {settings.APPLESCRIPT_PATH}'
    try:
        output = (
            subprocess.check_output(cmd, shell=True, stderr=subprocess.STDOUT)
            .decode('utf-8')
            .splitlines()
        )
        if sort:
            output = sorted(output)
    except subprocess.CalledProcessError:
        output = []
    yield from output
